This repository is mainly a dependency for https://github.com/sdss/marvin, containing some core
logic and functions pertaining to Flask API infrastructure for the Marvin API.  It is not useable as a product or python package by itself.  The original ideas behind ``marvin_brain`` has largely been expanded into [sdss_brain](https://github.com/sdss/sdss_brain) and [valis](https://github.com/sdss/valis).


Useful links
------------

- GitHub: https://github.com/sdss/marvin_brain
- Issues: https://github.com/sdss/marvin_brain/issues
